@@ -26,10 +26,12 @@ import (
 // Gatherer is the APM data collection module in Satellite.
 type Gatherer interface {
 	api.Module
+	// PartitionCount is the all partition counter of gatherer. All event is partitioned.
+	PartitionCount() int
 	// OutputDataChannel is a blocking channel to transfer the apm data to the upstream processor module.
-	OutputDataChannel() <-chan *queue.SequenceEvent
+	OutputDataChannel(partition int) <-chan *queue.SequenceEvent
 	// Ack the sent offset.
-	Ack(lastOffset event.Offset)
+	Ack(lastOffset *event.Offset)
 	// Inject the Processor module.
 	SetProcessor(processor api.Module) error
 }
