@@ -20,6 +20,7 @@ package grpc
 import (
 	"context"
 	"fmt"
+	"math"
 
 	"github.com/sirupsen/logrus"
 	"google.golang.org/grpc"
@@ -41,7 +42,7 @@ type Client struct {
 	// server finder config
 	ServerFinderConfig resolvers.ServerFinderConfig `mapstructure:",squash"`
 
-	EnableTLS          bool   `mapstructure:"enable_TLS"`           // Enable TLS connect to server
+	EnableTLS          bool   `mapstructure:"enable_tls"`           // Enable TLS connect to server
 	ClientPemPath      string `mapstructure:"client_pem_path"`      // The file path of client.pem. The config only works when opening the TLS switch.
 	ClientKeyPath      string `mapstructure:"client_key_path"`      // The file path of client.key. The config only works when opening the TLS switch.
 	CaPemPath          string `mapstructure:"ca_pem_path"`          // The file path oca.pem. The config only works when opening the TLS switch.
@@ -97,7 +98,7 @@ kubernetes_config:
     port: 11800
 
 # The TLS switch (default false).
-enable_TLS: false
+enable_tls: false
 
 # The file path of client.pem. The config only works when opening the TLS switch.
 client_pem_path: ""
@@ -146,7 +147,7 @@ func (c *Client) Prepare() error {
 	if err != nil {
 		return fmt.Errorf("cannot build grpc target: %v", err)
 	}
-	client, err := grpc.Dial(target, *cfg...)
+	client, err := grpc.NewClient(target, *cfg...)
 	if err != nil {
 		return fmt.Errorf("cannot connect to grpc server: %v", err)
 	}
@@ -183,5 +184,12 @@ type logrusGrpcLoggerV2 struct {
 }
 
 func (l *logrusGrpcLoggerV2) V(level int) bool {
-	return l.Logger.IsLevelEnabled(logrus.Level(level))
+	return l.Logger.IsLevelEnabled(logrus.Level(intToUint32(level)))
+}
+
+func intToUint32(value int) uint32 {
+	if value < 0 || value > math.MaxUint32 {
+		return 0
+	}
+	return uint32(value)
 }
