@@ -23,7 +23,10 @@ import (
 	"github.com/apache/skywalking-satellite/plugins/forwarder/api"
 )
 
-const Name = "none-fallbacker"
+const (
+	Name     = "none-fallbacker"
+	ShowName = "None Fallbacker"
+)
 
 type Fallbacker struct {
 	config.CommonFields
@@ -33,6 +36,10 @@ func (f *Fallbacker) Name() string {
 	return Name
 }
 
+func (f *Fallbacker) ShowName() string {
+	return ShowName
+}
+
 func (f *Fallbacker) Description() string {
 	return "The fallbacker would do nothing when facing failure data."
 }
