@@ -78,17 +78,17 @@ func (f *Forwarder) ForwardType() v1.SniffType {
 	return v1.SniffType_ConfigurationDiscoveryServiceType
 }
 
-func (f *Forwarder) SyncForward(e *v1.SniffData) (*v1.SniffData, error) {
+func (f *Forwarder) SyncForward(e *v1.SniffData) (*v1.SniffData, grpc.ClientStream, error) {
 	query := e.GetConfigurationSyncRequest()
 	if query != nil {
 		commands, err := f.cdsClient.FetchConfigurations(context.Background(), query)
 		if err != nil {
-			return nil, err
+			return nil, nil, err
 		}
-		return &v1.SniffData{Data: &v1.SniffData_Commands{Commands: commands}}, nil
+		return &v1.SniffData{Data: &v1.SniffData_Commands{Commands: commands}}, nil, nil
 	}
 
-	return nil, fmt.Errorf("unsupport data")
+	return nil, nil, fmt.Errorf("unsupport data")
 }
 
 func (f *Forwarder) SupportedSyncInvoke() bool {
