@@ -22,6 +22,7 @@ import (
 	"reflect"
 
 	"github.com/Shopify/sarama"
+	"google.golang.org/grpc"
 
 	"github.com/apache/skywalking-satellite/internal/pkg/config"
 	"github.com/apache/skywalking-satellite/internal/satellite/event"
@@ -94,8 +95,8 @@ func (f *Forwarder) ForwardType() v1.SniffType {
 	return v1.SniffType_Logging
 }
 
-func (f *Forwarder) SyncForward(_ *v1.SniffData) (*v1.SniffData, error) {
-	return nil, fmt.Errorf("unsupport sync forward")
+func (f *Forwarder) SyncForward(_ *v1.SniffData) (*v1.SniffData, grpc.ClientStream, error) {
+	return nil, nil, fmt.Errorf("unsupport sync forward")
 }
 
 func (f *Forwarder) SupportedSyncInvoke() bool {
